"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const path_1 = __importDefault(require("path"));
const utils_1 = require("../../src/utils");
const languages_1 = require("./languages");
const themes_1 = require("./themes");
const types_joi_1 = __importDefault(require("types-joi"));
const utils_2 = require("../utils");
(async () => {
    console.log("Deleting old metadata.");
    await Promise.all([
        fs_extra_1.rm(path_1.default.join(await utils_1.REPO_ROOT, "metadata", "grammars"), { force: true, recursive: true }),
        fs_extra_1.rm(path_1.default.join(await utils_1.REPO_ROOT, "metadata", "themes"), { force: true, recursive: true }),
    ]);
    console.log("Collecting available extensions:");
    const extensions = await collectExtensions();
    console.log(`\n\nInspecting ${extensions.length} possible extensions:`);
    for (let i = 0; i < extensions.length; i++) {
        const packagePath = extensions[i];
        console.log(`${(i + 1).toString().padStart(3, " ")} | ${path_1.default.relative(await utils_1.REPO_ROOT, packagePath)}`);
        const packageJson = await fs_extra_1.readJson(packagePath);
        const packageDir = path_1.default.dirname(packagePath);
        const validated = types_joi_1.default.attempt(packageJson, utils_2.PACKAGE_SCHEME);
        await Promise.all([
            // extraction
            themes_1.extractThemes(validated, packageDir),
            languages_1.extractLanguages(validated, packageDir),
        ]);
    }
    await Promise.all([
        // metadata
        themes_1.writeThemesFile(),
        languages_1.writeLanguagesFile(),
        languages_1.writeGrammarsFile(),
    ]);
})();
async function collectExtensions() {
    const extensions = [];
    await search(path_1.default.join(await utils_1.REPO_ROOT, "vscode"));
    return extensions;
    async function search(currentDir) {
        const possiblePackage = path_1.default.join(currentDir, "package.json");
        if (await fs_extra_1.pathExists(possiblePackage)) {
            extensions.push(possiblePackage);
            console.log(`${extensions.length.toString().padStart(3, " ")} | ${path_1.default.relative(await utils_1.REPO_ROOT, possiblePackage)}`);
        }
        const children = await fs_extra_1.readdir(currentDir);
        await Promise.all(children.map(async (child) => {
            if (child === "node_modules") {
                return;
            }
            const childDir = path_1.default.join(currentDir, child);
            if (!(await fs_extra_1.stat(childDir)).isDirectory()) {
                return;
            }
            await search(childDir);
        }));
    }
}
//# sourceMappingURL=index.js.map