"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeThemesFile = exports.extractThemes = void 0;
const path_1 = __importDefault(require("path"));
const metadata_1 = require("../../src/themes/metadata");
const assert_1 = __importDefault(require("assert"));
const utils_1 = require("../utils");
const utils_2 = require("../../src/utils");
const theme_resolver_1 = require("../../src/themes/theme-resolver");
const THEMES = [];
async function extractThemes(contents, packageDir) {
    for (const { id: label, uiTheme, path: themeRelativePath } of contents.contributes?.themes || []) {
        const id = label.replace(/[+]/g, "-plus").replace(/[\s]/g, "-").toLowerCase();
        const variation = extractVariation(uiTheme);
        assert_1.default(THEMES.every((t) => t.id !== id), "Duplicate definitions of theme: " + id);
        THEMES.push({ id, label, variation });
        const themeFullPath = path_1.default.join(packageDir, themeRelativePath);
        const themeContents = await theme_resolver_1.resolveTheme(themeFullPath, variation);
        const themeDestination = path_1.default.join(await utils_2.REPO_ROOT, "metadata", "themes", id + ".json");
        await utils_1.writeFormattedJSON(themeDestination, themeContents);
        console.log(`    | 🖌 ${id}`);
    }
}
exports.extractThemes = extractThemes;
async function writeThemesFile() {
    THEMES.sort((a, b) => {
        if (a.variation !== b.variation) {
            return a.variation.localeCompare(b.variation);
        }
        return a.id.localeCompare(b.id);
    });
    const destination = path_1.default.join(await utils_2.REPO_ROOT, "metadata", "themes.json");
    await utils_1.writeFormattedJSON(destination, THEMES);
}
exports.writeThemesFile = writeThemesFile;
function extractVariation(uiTheme) {
    switch (uiTheme) {
        case "vs":
            return metadata_1.ThemeVariation.Light;
        case "vs-dark":
            return metadata_1.ThemeVariation.Dark;
        case "hc-black":
            return metadata_1.ThemeVariation.HighContrast;
        default:
            throw new Error("Unrecognized uiTheme: " + uiTheme);
    }
}
//# sourceMappingURL=themes.js.map