"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IconRenderingRequest = exports.ICON_SIZE = void 0;
const fs_extra_1 = require("fs-extra");
const path_1 = __importDefault(require("path"));
const url_1 = __importDefault(require("url"));
const puppeteer_1 = __importDefault(require("puppeteer"));
const utils_1 = require("../../../src/utils");
const requests_1 = require("./requests");
exports.ICON_SIZE = 18;
class IconRenderingRequest extends requests_1.BaseRenderingRequest {
    constructor(languageId) {
        super();
        this.languageId = languageId;
    }
    async run(imagePath) {
        const templateDestination = await this.generateTemplate(imagePath);
        const browser = await puppeteer_1.default.launch({
            args: ["--no-sandbox"],
        });
        const page = await browser.newPage();
        await page.goto(url_1.default.pathToFileURL(templateDestination).toString());
        await page.evaluateHandle("document.fonts.ready");
        const buffer = await page.screenshot({
            clip: {
                x: 0,
                y: 0,
                height: exports.ICON_SIZE,
                width: exports.ICON_SIZE,
            },
            omitBackground: true,
            type: "png",
        });
        if (!Buffer.isBuffer(buffer)) {
            throw new Error("Expected a buffer out of puppeteer.");
        }
        await fs_extra_1.writeFile(imagePath, buffer);
        await page.close();
        await browser.close();
    }
    async generateTemplate(imagePath) {
        const templatePath = path_1.default.join(__dirname, "language-icon-template.html");
        const templateContents = await fs_extra_1.readFile(templatePath, "utf8");
        const templateDestinationDir = path_1.default.join(await utils_1.REPO_ROOT, "out/icon-templates");
        if (!(await fs_extra_1.pathExists(templateDestinationDir))) {
            await fs_extra_1.mkdirp(templateDestinationDir);
        }
        const templateDestination = path_1.default.join(templateDestinationDir, path_1.default.basename(imagePath, ".png") + ".html");
        const setiFontPath = path_1.default.join(await utils_1.REPO_ROOT, "vscode/extensions/theme-seti/icons/seti.woff");
        const setiIconList = await utils_1.readAndCacheFile(await utils_1.REPO_ROOT, "vscode/extensions/theme-seti/icons/vs-seti-icon-theme.json");
        const iconShorthand = setiIconList.languageIds[this.languageId] || setiIconList.fileExtensions[this.languageId] || setiIconList.file;
        const icon = setiIconList.iconDefinitions[iconShorthand];
        await fs_extra_1.writeFile(templateDestination, templateContents
            .replaceAll("__SETI_FONT_PATH__", url_1.default.pathToFileURL(setiFontPath).toString())
            .replaceAll("__ICON_SIZE__", `${exports.ICON_SIZE}px`)
            .replaceAll("__ICON_FONT_COLOR__", icon.fontColor)
            .replaceAll("__ICON_FONT_CHARACTER__", icon.fontCharacter));
        return templateDestination;
    }
}
exports.IconRenderingRequest = IconRenderingRequest;
//# sourceMappingURL=icon-request.js.map