"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.flushRequests = exports.addRequest = exports.BaseRenderingRequest = void 0;
const fs_extra_1 = require("fs-extra");
const path_1 = __importDefault(require("path"));
const readline_1 = __importDefault(require("readline"));
const os_1 = __importDefault(require("os"));
const clipboardy_1 = __importDefault(require("clipboardy"));
const utils_1 = require("../../../src/utils");
const cli_progress_1 = __importDefault(require("cli-progress"));
const promise_queue_1 = __importDefault(require("promise-queue"));
const assert_1 = __importDefault(require("assert"));
class BaseRenderingRequest {
}
exports.BaseRenderingRequest = BaseRenderingRequest;
const KEYS = [];
const REQUESTS = [];
function addRequest(request) {
    const key = `__RENDERING_REQUEST_${REQUESTS.length + 1}__`;
    KEYS.push(key);
    REQUESTS.push(request);
    return key;
}
exports.addRequest = addRequest;
async function flushRequests(contents) {
    const imagesDir = path_1.default.join(await utils_1.REPO_ROOT, "out", "readme-renders");
    if (await fs_extra_1.pathExists(imagesDir)) {
        await fs_extra_1.rm(imagesDir, { recursive: true });
    }
    await fs_extra_1.mkdirp(imagesDir);
    console.log(`Writing images to: ${imagesDir}`);
    await executeAllRequests(imagesDir);
    const urls = await runUploadWorkflow(imagesDir);
    assert_1.default(KEYS.length === urls.length, `Expected ${KEYS.length} images but parsed ${urls.length} instead.`);
    for (let i = 0; i < KEYS.length; i++) {
        contents = contents.replaceAll(KEYS[i], urls[i]);
    }
    return contents;
}
exports.flushRequests = flushRequests;
async function executeAllRequests(imagesDir) {
    const bar = new cli_progress_1.default.Bar({
        clearOnComplete: false,
        hideCursor: true,
        format: `[{bar}] {percentage}% of images ({value}/{total})`,
    });
    bar.start(REQUESTS.length, 0);
    const PARALLELISM = os_1.default.cpus().length;
    process.setMaxListeners(PARALLELISM);
    const queue = new promise_queue_1.default(/* maxPendingPromises */ PARALLELISM);
    await Promise.all(REQUESTS.map(async (request, requestIndex) => {
        await queue.add(async () => {
            const imagePath = path_1.default.join(imagesDir, `${KEYS[requestIndex]}.png`);
            await request.run(imagePath);
        });
        bar.increment(1);
    }));
    bar.stop();
    return imagesDir;
}
async function runUploadWorkflow(imagesDir) {
    await clipboardy_1.default.write(imagesDir);
    const rl = readline_1.default.createInterface({
        input: process.stdin,
        output: process.stdout,
    });
    await new Promise((resolve) => rl.question("Path copied to clipboard. Please copy back the generated markdown tags, and press any key.", () => {
        rl.close();
        resolve();
    }));
    const tags = await clipboardy_1.default.read();
    const urls = tags
        .trim()
        .split("\n")
        .map((line) => {
        const match = /^!\[__RENDERING_REQUEST_\d+__\]\((https:\/\/.*\.png)\)$/.exec(line);
        if (!match) {
            throw new Error("Invalid line format: " + line);
        }
        return match[1];
    });
    return urls;
}
//# sourceMappingURL=requests.js.map