"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TerminalRenderingRequest = void 0;
const fs_extra_1 = require("fs-extra");
const terminal_screenshot_1 = require("terminal-screenshot");
const metadata_1 = require("../../../src/themes/metadata");
const chalk_1 = __importDefault(require("chalk"));
const utils_1 = require("../../utils");
const assert_1 = __importDefault(require("assert"));
const requests_1 = require("./requests");
class TerminalRenderingRequest extends requests_1.BaseRenderingRequest {
    constructor(themeId, factory, margin, command) {
        super();
        this.themeId = themeId;
        this.factory = factory;
        this.margin = margin;
        this.command = command;
    }
    async run(imagePath) {
        const themes = await metadata_1.getSupportedThemes();
        const variation = themes.find((t) => t.id === this.themeId)?.variation;
        assert_1.default(variation, "Cannot detect variation of theme: " + this.themeId);
        const lines = await this.factory();
        if (this.command) {
            const backgroundBrush = chalk_1.default.hex(utils_1.getVariationForeground(variation));
            lines.splice(0, 0, backgroundBrush(`$ ${this.command}`), backgroundBrush(""));
        }
        const image = await terminal_screenshot_1.renderScreenshot({
            data: lines.join("\r\n"),
            type: "png",
            backgroundColor: utils_1.getVariationBackground(variation),
            margin: this.margin,
        });
        await fs_extra_1.writeFile(imagePath, image);
    }
}
exports.TerminalRenderingRequest = TerminalRenderingRequest;
//# sourceMappingURL=terminal-request.js.map