"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getVariationForeground = exports.getVariationBackground = exports.writeFormattedJSON = exports.PACKAGE_SCHEME = void 0;
const fs_extra_1 = require("fs-extra");
const prettier_1 = __importDefault(require("prettier"));
const assert_1 = __importDefault(require("assert"));
const types_joi_1 = __importDefault(require("types-joi"));
const path_1 = __importDefault(require("path"));
const metadata_1 = require("../src/themes/metadata");
exports.PACKAGE_SCHEME = types_joi_1.default
    .object({
    contributes: types_joi_1.default
        .object({
        themes: types_joi_1.default.array().items(types_joi_1.default.object({
            id: types_joi_1.default.string().required(),
            uiTheme: types_joi_1.default.string().required(),
            label: types_joi_1.default.string(),
            path: types_joi_1.default
                .string()
                .required()
                .regex(/\.json$/),
        })),
        languages: types_joi_1.default.array().items(types_joi_1.default.object({
            id: types_joi_1.default.string().required(),
            extensions: types_joi_1.default.array().items(types_joi_1.default.string()),
            filenames: types_joi_1.default.array().items(types_joi_1.default.string()),
            aliases: types_joi_1.default.array().items(types_joi_1.default.string()),
            mimetypes: types_joi_1.default.array().items(types_joi_1.default.string()),
            filenamePatterns: types_joi_1.default.array().items(types_joi_1.default.string()),
            configuration: types_joi_1.default.string(),
            firstLine: types_joi_1.default.string(),
        })),
        grammars: types_joi_1.default.array().items(types_joi_1.default.object({
            language: types_joi_1.default.string(),
            scopeName: types_joi_1.default.string().required(),
            path: types_joi_1.default.string().required(),
            embeddedLanguages: types_joi_1.default.object(),
            tokenTypes: types_joi_1.default.object(),
            injectTo: types_joi_1.default.array().items(types_joi_1.default.string()),
        })),
    })
        .unknown(true),
})
    .required()
    .unknown(true);
async function writeFormattedJSON(destination, contents) {
    const config = await prettier_1.default.resolveConfig(destination);
    assert_1.default(config, "prettier config must be present.");
    const formatted = prettier_1.default.format(JSON.stringify(contents), {
        ...config,
        filepath: destination,
    });
    await fs_extra_1.mkdirp(path_1.default.dirname(destination));
    await fs_extra_1.writeFile(destination, formatted);
}
exports.writeFormattedJSON = writeFormattedJSON;
function getVariationBackground(variation) {
    switch (variation) {
        case metadata_1.ThemeVariation.Dark:
        case metadata_1.ThemeVariation.HighContrast:
            return "#000000";
        case metadata_1.ThemeVariation.Light:
            return "#FFFFFF";
    }
}
exports.getVariationBackground = getVariationBackground;
function getVariationForeground(variation) {
    switch (variation) {
        case metadata_1.ThemeVariation.Dark:
        case metadata_1.ThemeVariation.HighContrast:
            return "#FFFFFF";
        case metadata_1.ThemeVariation.Light:
            return "#000000";
    }
}
exports.getVariationForeground = getVariationForeground;
//# sourceMappingURL=utils.js.map