"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const language_detection_1 = require("../../../src/languages/language-detection");
const utils_1 = require("../utils");
const create_suite_1 = require("../create-suite");
const joi_1 = __importDefault(require("joi"));
const path_1 = __importDefault(require("path"));
const highlight_diagnostics_1 = require("../../../src/highlighting/highlight-diagnostics");
const options_1 = require("../../../src/options");
const DIAGNOSTIC_SCHEMA = joi_1.default
    .object({
    severity: joi_1.default
        .string()
        .required()
        .valid(options_1.DiagnosticSeverity.Error, options_1.DiagnosticSeverity.Warning, options_1.DiagnosticSeverity.Info, options_1.DiagnosticSeverity.Hint),
    range: joi_1.default
        .object({
        from: joi_1.default.object({ line: joi_1.default.number().required(), column: joi_1.default.number().required() }).required(),
        to: joi_1.default.object({ line: joi_1.default.number().required(), column: joi_1.default.number().required() }).required(),
    })
        .required(),
})
    .required();
create_suite_1.createHighlightingTestSuite(__dirname, async ({ testDir, themeId, languageId }) => {
    const sourcePath = await utils_1.resolveSourceFile(testDir, "source");
    const source = await fs_extra_1.readFile(sourcePath, "utf8");
    expect(languageId).toEqual(await language_detection_1.detectLanguage(sourcePath, source));
    const diagnostic = await fs_extra_1.readJson(path_1.default.join(testDir, "details.json"));
    joi_1.default.attempt(diagnostic, DIAGNOSTIC_SCHEMA);
    const lines = await highlight_diagnostics_1.highlightDiagnostic({
        source,
        range: diagnostic.range,
        severity: diagnostic.severity,
        width: utils_1.TESTS_WIDTH,
        languageIdOrPath: languageId,
        themeIdOrPath: themeId,
    });
    return {
        lines,
        sources: [source],
    };
});
//# sourceMappingURL=diagnostics.test.js.map