"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const language_detection_1 = require("../../../src/languages/language-detection");
const utils_1 = require("../utils");
const create_suite_1 = require("../create-suite");
const highlight_diffs_1 = require("../../../src/highlighting/highlight-diffs");
create_suite_1.createHighlightingTestSuite(__dirname, async ({ testDir, themeId, languageId }) => {
    const beforePath = await utils_1.resolveSourceFile(testDir, "before");
    const beforeSource = await fs_extra_1.readFile(beforePath, "utf8");
    expect(languageId).toEqual(await language_detection_1.detectLanguage(beforePath, beforeSource));
    const afterPath = await utils_1.resolveSourceFile(testDir, "after");
    const afterSource = await fs_extra_1.readFile(afterPath, "utf8");
    expect(languageId).toEqual(await language_detection_1.detectLanguage(afterPath, afterSource));
    const lines = await highlight_diffs_1.highlightDiff({
        beforeSource,
        afterSource,
        width: utils_1.TESTS_WIDTH,
        languageIdOrPath: languageId,
        themeIdOrPath: themeId,
    });
    return {
        lines,
        sources: [beforeSource, afterSource],
    };
});
//# sourceMappingURL=diffs.test.js.map