"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RequestWriter = void 0;
const path_1 = __importDefault(require("path"));
const os_1 = __importDefault(require("os"));
const fs_extra_1 = require("fs-extra");
const REQUESTS_DIR = path_1.default.join(os_1.default.tmpdir(), "rendering-requests");
class RequestWriter {
    constructor(suiteId) {
        this.suiteId = suiteId;
        this.requests = [];
    }
    add(request) {
        this.requests.push(request);
    }
    async writeToDisk() {
        await fs_extra_1.mkdirp(REQUESTS_DIR);
        await fs_extra_1.writeJson(path_1.default.join(REQUESTS_DIR, this.suiteId + ".json"), this.requests);
    }
    static async deserialize() {
        const results = new Map();
        if (!(await fs_extra_1.pathExists(REQUESTS_DIR))) {
            return results;
        }
        const fileNames = await fs_extra_1.readdir(REQUESTS_DIR);
        await Promise.all(fileNames.map(async (fileName) => {
            const suiteId = path_1.default.basename(fileName, path_1.default.extname(fileName));
            const requests = await fs_extra_1.readJson(path_1.default.join(REQUESTS_DIR, fileName));
            results.set(suiteId, requests);
        }));
        await fs_extra_1.rm(REQUESTS_DIR, { recursive: true });
        return results;
    }
}
exports.RequestWriter = RequestWriter;
//# sourceMappingURL=requests.js.map