"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const highlight_diagnostics_1 = require("../src/highlighting/highlight-diagnostics");
const highlight_diffs_1 = require("../src/highlighting/highlight-diffs");
const highlight_source_1 = require("../src/highlighting/highlight-source");
const options_1 = require("../src/options");
it("can trim long lines in sources", async () => {
    const result = await highlight_source_1.highlightSource({
        source: `
Short line.
A really long line that will definetely exceed the width limit.
Another short line.
`.trim(),
        width: 50,
    });
    expect(result).toMatchInlineSnapshot(`
    Array [
      " 1 │ Short·line.                                  ",
      " 2 │ A·really·long·line·that·will·definetely·exce…",
      " 3 │ Another·short·line.                          ",
    ]
  `);
});
it("can trim long lines in diffs", async () => {
    const result = await highlight_diffs_1.highlightDiff({
        beforeSource: `
Short line.
An old long line that will definetely exceed the width limit.
Another short line.
`.trim(),
        afterSource: `
Short line.
A new long line that will definetely exceed the width limit.
Another short line.
`.trim(),
        width: 50,
    });
    expect(result).toMatchInlineSnapshot(`
    Array [
      " 1 │ 1 │ Short·line.                              ",
      " 2 │   │ An·old·long·line·that·will·definetely·ex…",
      "   │ 2 │ A·new·long·line·that·will·definetely·exc…",
      " 3 │ 3 │ Another·short·line.                      ",
    ]
  `);
});
it("can trim long lines in diagnostics", async () => {
    const result = await highlight_diagnostics_1.highlightDiagnostic({
        source: `
Short line.
A really long line that will definetely exceed the width limit.
Another short line.
`.trim(),
        severity: options_1.DiagnosticSeverity.Error,
        range: {
            from: { line: 1, column: 9 },
            to: { line: 1, column: 18 },
        },
        width: 50,
    });
    expect(result).toMatchInlineSnapshot(`
    Array [
      " 1 │ Short·line.                                  ",
      " 2 │ A·really·long·line·that·will·definetely·exce…",
      "   │          ~~~~~~~~~                           ",
      " 3 │ Another·short·line.                          ",
    ]
  `);
});
it("does not print elepsis on lines with maximum width allowed", async () => {
    const result = await highlight_source_1.highlightSource({
        source: `
4567
45678
456789
`.trim(),
        width: 10,
    });
    expect(result).toMatchInlineSnapshot(`
    Array [
      " 1 │ 4567 ",
      " 2 │ 45678",
      " 3 │ 4567…",
    ]
  `);
});
it("trims line endings correctly with rendering tabs whitespace", async () => {
    const result = await highlight_source_1.highlightSource({
        source: `
123 567890
123\t890
`.trim(),
        width: 14,
    });
    expect(result).toMatchInlineSnapshot(`
    Array [
      " 1 │ 123·5678…",
      " 2 │ 123→   8…",
    ]
  `);
});
//# sourceMappingURL=trimming.test.js.map